# NECInputClean.awk:
#	This GAWK utility preprocesses and input card deck for NEC by:
#	a) removing leading & trailing non-printing characters from each line.
#	b) removing blank lines.
#	c) reformatting GW wire geometry cards to line up the coordinates in columns.
#	d) time-stamping the top of the card deck.
#
# Call from command line prompt:
#	gawk -f NECInputClean.awk filein >fileout
#
# Requires:
#	gawk.exe
#
# Inputs:
#	filein - filename (including extension) of raw input card deck.
#
# Outputs:
#	fileout - filename (including extension) for cleaned-up NEC input card deck.
#======================================
#
# Note: GAWK automatically strips leading and trailing white space characters,
#	whenever the field separator parameter FS is defined as the default.
#


NF>0 {				# If blank card, don't save it; go to next card.
   if ( $1!="CM") {		# If comment card, don't tinker with the format.
      gsub( /\t/, " ", $0)		# Replace tab with space in the card.
      gsub( / +/, " ", $0)		# Replace multiple spaces with one space.
   }

   if ( $1=="CE") {		# If end of comments, timestamp the card deck.
      format = "CM Card deck created %y %b %d %a %H:%M:%S %z"
      printf "%s\n", strftime( format)
   }

   if ( $1=="GW") {		# If wire geometry card, columnize the data.
      # Wire coordinates must be long enough to handle current source locations of form 9901.0000.
      printf "%s %3i %3i % 9.4f % 9.4f % 9.4f  % 9.4f % 9.4f % 9.4f   %6.4f", $1, $2, $3, $4, $5, $6, $7, $8, $9, $10
      if ( NF>10) {
         # Tack on the rest of the card.
         for( i=11; i<=NF; i++) printf " %s", $i
      }
      printf "\n"		# Done with this GW card.
   }
   else print $0
}
